@@ -4,9 +4,7 @@
 from __future__ import print_function
 from collections import OrderedDict
 
-import click
 import datetime
-import errno
 import git
 import json
 import logging
@@ -15,8 +13,6 @@ import re
 import requests
 import rich.console
 import rich.table
-import subprocess
-import sys
 
 import nf_core.utils
 
@@ -71,7 +67,7 @@ def get_local_wf(workflow, revision=None):
     log.info("Downloading workflow: {} ({})".format(workflow, revision))
     pull_cmd = f"nextflow pull {workflow}"
     if revision is not None:
-        pull_cmd += f"-r {revision}"
+        pull_cmd += f" -r {revision}"
     nf_pull_output = nf_core.utils.nextflow_cmd(pull_cmd)
     local_wf = LocalWorkflow(workflow)
     local_wf.get_local_nf_workflow_details()
@@ -259,11 +255,17 @@ class Workflows(object):
             else:
                 table.add_row(*rowdata)
 
-        # Print summary table
-        return table
+        if len(filtered_workflows) > 0:
+            # Print summary table
+            return table
+        else:
+            return_str = f"No pipelines found using filter keywords: '{', '.join(self.keyword_filters)}'"
+            if self.keyword_filters == ("modules",):
+                return_str += "\n\n:bulb: Did you mean 'nf-core modules list' instead?"
+            return return_str
 
     def print_json(self):
-        """ Dump JSON of all parsed information """
+        """Dump JSON of all parsed information"""
         return json.dumps(
             {"local_workflows": self.local_workflows, "remote_workflows": self.remote_workflows},
             default=lambda o: o.__dict__,
@@ -308,10 +310,10 @@ class RemoteWorkflow(object):
 
 
 class LocalWorkflow(object):
-    """ Class to handle local workflows pulled by nextflow """
+    """Class to handle local workflows pulled by nextflow"""
 
     def __init__(self, name):
-        """ Initialise the LocalWorkflow object """
+        """Initialise the LocalWorkflow object"""
         self.full_name = name
         self.repository = None
         self.local_path = None
@@ -324,7 +326,7 @@ class LocalWorkflow(object):
         self.last_pull_pretty = None
 
     def get_local_nf_workflow_details(self):
-        """ Get full details about a local cached workflow """
+        """Get full details about a local cached workflow"""
 
         if self.local_path is None:
 
