@@ -21,7 +21,8 @@ import yaml
 import operator
 
 import nf_core.utils
-import nf_core.modules.pipeline_modules
+
+from .modules_repo import ModulesRepo
 
 
 log = logging.getLogger(__name__)
@@ -47,7 +48,7 @@ class ModulesTestYmlBuilder(object):
         self.tests = []
 
     def run(self):
-        """ Run build steps """
+        """Run build steps"""
         if not self.no_prompts:
             log.info(
                 "[yellow]Press enter to use default values [cyan bold](shown in brackets) [yellow]or type your own responses"
@@ -58,19 +59,19 @@ class ModulesTestYmlBuilder(object):
         self.print_test_yml()
 
     def check_inputs(self):
-        """ Do more complex checks about supplied flags. """
+        """Do more complex checks about supplied flags."""
 
         # Get the tool name if not specified
         if self.module_name is None:
-            modules_repo = nf_core.modules.pipeline_modules.ModulesRepo()
+            modules_repo = ModulesRepo()
             modules_repo.get_modules_file_tree()
             self.module_name = questionary.autocomplete(
                 "Tool name:",
                 choices=modules_repo.modules_avail_module_names,
                 style=nf_core.utils.nfcore_question_style,
             ).ask()
-        self.module_dir = os.path.join("software", *self.module_name.split("/"))
-        self.module_test_main = os.path.join("tests", "software", *self.module_name.split("/"), "main.nf")
+        self.module_dir = os.path.join("modules", *self.module_name.split("/"))
+        self.module_test_main = os.path.join("tests", "modules", *self.module_name.split("/"), "main.nf")
 
         # First, sanity check that the module directory exists
         if not os.path.isdir(self.module_dir):
@@ -85,7 +86,7 @@ class ModulesTestYmlBuilder(object):
 
         # Get the output YAML file / check it does not already exist
         while self.test_yml_output_path is None:
-            default_val = f"tests/software/{self.module_name}/test.yml"
+            default_val = f"tests/modules/{self.module_name}/test.yml"
             if self.no_prompts:
                 self.test_yml_output_path = default_val
             else:
@@ -113,7 +114,7 @@ class ModulesTestYmlBuilder(object):
             )
 
     def scrape_workflow_entry_points(self):
-        """ Find the test workflow entry points from main.nf """
+        """Find the test workflow entry points from main.nf"""
         log.info(f"Looking for test workflow entry points: '{self.module_test_main}'")
         with open(self.module_test_main, "r") as fh:
             for line in fh:
@@ -159,7 +160,7 @@ class ModulesTestYmlBuilder(object):
 
         while ep_test["command"] == "":
             default_val = (
-                f"nextflow run tests/software/{self.module_name} -entry {entry_point} -c tests/config/nextflow.config"
+                f"nextflow run tests/modules/{self.module_name} -entry {entry_point} -c tests/config/nextflow.config"
             )
             if self.no_prompts:
                 ep_test["command"] = default_val
@@ -170,8 +171,7 @@ class ModulesTestYmlBuilder(object):
             mod_name_parts = self.module_name.split("/")
             tag_defaults = []
             for idx in range(0, len(mod_name_parts)):
-                tag_defaults.append("_".join(mod_name_parts[: idx + 1]))
-            tag_defaults.append(entry_point.replace("test_", ""))
+                tag_defaults.append("/".join(mod_name_parts[: idx + 1]))
             # Remove duplicates
             tag_defaults = list(set(tag_defaults))
             if self.no_prompts:
@@ -197,7 +197,7 @@ class ModulesTestYmlBuilder(object):
         return md5sum
 
     def create_test_file_dict(self, results_dir):
-        """ Walk through directory and collect md5 sums """
+        """Walk through directory and collect md5 sums"""
         test_files = []
         for root, dir, file in os.walk(results_dir):
             for elem in file:
@@ -211,14 +211,13 @@ class ModulesTestYmlBuilder(object):
 
         return test_files
 
-    def get_md5_sums(self, entry_point, command):
+    def get_md5_sums(self, entry_point, command, results_dir=None, results_dir_repeat=None):
         """
         Recursively go through directories and subdirectories
         and generate tuples of (<file_path>, <md5sum>)
         returns: list of tuples
         """
 
-        results_dir = None
         run_this_test = False
         while results_dir is None:
             if self.run_tests or run_this_test:
@@ -235,15 +234,18 @@ class ModulesTestYmlBuilder(object):
                     results_dir = None
 
         test_files = self.create_test_file_dict(results_dir=results_dir)
-        test_files_repeat = self.create_test_file_dict(results_dir=results_dir_repeat)
 
-        # Compare both test.yml files
-        for i in range(len(test_files)):
-            if not test_files[i]["md5sum"] == test_files_repeat[i]["md5sum"]:
-                test_files[i].pop("md5sum")
-                test_files[i][
-                    "contains"
-                ] = "# TODO nf-core: file md5sum was variable, please replace this text with a string found in the file instead"
+        # If test was repeated, compare the md5 sums
+        if results_dir_repeat:
+            test_files_repeat = self.create_test_file_dict(results_dir=results_dir_repeat)
+
+            # Compare both test.yml files
+            for i in range(len(test_files)):
+                if not test_files[i]["md5sum"] == test_files_repeat[i]["md5sum"]:
+                    test_files[i].pop("md5sum")
+                    test_files[i][
+                        "contains"
+                    ] = "[ # TODO nf-core: file md5sum was variable, please replace this text with a string found in the file instead ]"
 
         if len(test_files) == 0:
             raise UserWarning(f"Could not find any test result files in '{results_dir}'")
@@ -251,7 +253,7 @@ class ModulesTestYmlBuilder(object):
         return test_files
 
     def run_tests_workflow(self, command):
-        """ Given a test workflow and an entry point, run the test workflow """
+        """Given a test workflow and an entry point, run the test workflow"""
 
         # The config expects $PROFILE and Nextflow fails if it's not set
         if os.environ.get("PROFILE") is None:
@@ -277,8 +279,9 @@ class ModulesTestYmlBuilder(object):
 
         tmp_dir = tempfile.mkdtemp()
         tmp_dir_repeat = tempfile.mkdtemp()
-        command += f" --outdir {tmp_dir}"
-        command_repeat = command + f" --outdir {tmp_dir_repeat}"
+        work_dir = tempfile.mkdtemp()
+        command_repeat = command + f" --outdir {tmp_dir_repeat} -work-dir {work_dir}"
+        command += f" --outdir {tmp_dir} -work-dir {work_dir}"
 
         log.info(f"Running '{self.module_name}' test with command:\n[violet]{command}")
         try:
